# TCP client connection

A simple TCP client/server connection to use the TCP protocol for sending and receiving envelopes.

## Usage

Add the connection to your AEA project: `aea add connection fetchai/tcp:0.9.0`.
